timespantools.TimespanInventory
===============================

.. abjad-lineage:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory

.. autoclass:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.all_are_contiguous
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.all_are_well_formed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.axis
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.duration
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.is_sorted
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.start_offset
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.storage_format
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.timespan
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.append
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.compute_logical_and
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.compute_logical_or
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.compute_logical_xor
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.count
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.extend
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.get_timespan_that_satisfies_time_relation
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.get_timespans_that_satisfy_time_relation
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.has_timespan_that_satisfies_time_relation
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.index
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.insert
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.pop
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.reflect
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.remove
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.remove_degenerate_timespans
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.repeat_to_stop_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.reverse
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.rotate
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.scale
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.sort
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.stretch
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.translate
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.translate_offsets
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__add__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__and__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__delslice__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__ge__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__getslice__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__gt__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__imul__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__le__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__len__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__lt__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__mul__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__rmul__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__setitem__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__setslice__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory.__sub__
   :noindex:
